Manager
=======

.. currentmodule:: bioregistry

.. autoclass:: Manager
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Manager.from_path
      ~Manager.get_appears_in
      ~Manager.get_bioportal_iri
      ~Manager.get_bioregistry_iri
      ~Manager.get_canonical_for
      ~Manager.get_curie_pattern
      ~Manager.get_default_iri
      ~Manager.get_depends_on
      ~Manager.get_example
      ~Manager.get_external
      ~Manager.get_formatted_iri
      ~Manager.get_has_canonical
      ~Manager.get_has_parts
      ~Manager.get_internal_prefix_map
      ~Manager.get_iri
      ~Manager.get_license_conflicts
      ~Manager.get_mapped_prefix
      ~Manager.get_miriam_curie
      ~Manager.get_miriam_iri
      ~Manager.get_n2t_iri
      ~Manager.get_name
      ~Manager.get_obofoundry_iri
      ~Manager.get_ols_iri
      ~Manager.get_part_of
      ~Manager.get_pattern
      ~Manager.get_pattern_map
      ~Manager.get_preferred_prefix
      ~Manager.get_prefix_list
      ~Manager.get_prefix_map
      ~Manager.get_provided_by
      ~Manager.get_provider_functions
      ~Manager.get_providers
      ~Manager.get_providers_list
      ~Manager.get_provides_for
      ~Manager.get_registry_invmap
      ~Manager.get_registry_map
      ~Manager.get_resource
      ~Manager.get_scholia_iri
      ~Manager.get_synonyms
      ~Manager.get_uri_format
      ~Manager.get_uri_prefix
      ~Manager.get_versions
      ~Manager.has_no_terms
      ~Manager.is_deprecated
      ~Manager.lookup_from
      ~Manager.normalize_curie
      ~Manager.normalize_parsed_curie
      ~Manager.normalize_prefix
      ~Manager.parse_curie
      ~Manager.rasterize
      ~Manager.write_registry

   .. rubric:: Methods Documentation

   .. automethod:: from_path
   .. automethod:: get_appears_in
   .. automethod:: get_bioportal_iri
   .. automethod:: get_bioregistry_iri
   .. automethod:: get_canonical_for
   .. automethod:: get_curie_pattern
   .. automethod:: get_default_iri
   .. automethod:: get_depends_on
   .. automethod:: get_example
   .. automethod:: get_external
   .. automethod:: get_formatted_iri
   .. automethod:: get_has_canonical
   .. automethod:: get_has_parts
   .. automethod:: get_internal_prefix_map
   .. automethod:: get_iri
   .. automethod:: get_license_conflicts
   .. automethod:: get_mapped_prefix
   .. automethod:: get_miriam_curie
   .. automethod:: get_miriam_iri
   .. automethod:: get_n2t_iri
   .. automethod:: get_name
   .. automethod:: get_obofoundry_iri
   .. automethod:: get_ols_iri
   .. automethod:: get_part_of
   .. automethod:: get_pattern
   .. automethod:: get_pattern_map
   .. automethod:: get_preferred_prefix
   .. automethod:: get_prefix_list
   .. automethod:: get_prefix_map
   .. automethod:: get_provided_by
   .. automethod:: get_provider_functions
   .. automethod:: get_providers
   .. automethod:: get_providers_list
   .. automethod:: get_provides_for
   .. automethod:: get_registry_invmap
   .. automethod:: get_registry_map
   .. automethod:: get_resource
   .. automethod:: get_scholia_iri
   .. automethod:: get_synonyms
   .. automethod:: get_uri_format
   .. automethod:: get_uri_prefix
   .. automethod:: get_versions
   .. automethod:: has_no_terms
   .. automethod:: is_deprecated
   .. automethod:: lookup_from
   .. automethod:: normalize_curie
   .. automethod:: normalize_parsed_curie
   .. automethod:: normalize_prefix
   .. automethod:: parse_curie
   .. automethod:: rasterize
   .. automethod:: write_registry
